<?php

namespace App\Http\Controllers;

use App\Mail\AccountConfirmation;
use App\Mail\OrderConfirmation;
use App\Mail\PasswordResetMail;
use App\Models\Blogs;
use App\Models\Blogscategories;
use App\Models\Cart;
use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\OrderDetails;
use App\Models\Orders;
use App\Models\Products;
use App\Models\Setting;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Auth;
use Hash;
use Illuminate\Support\Str;
use mysql_xdevapi\Collection;


class WebsiteController extends Controller
{
    public function home()
    {
        $categories = Categories::all();
        $products = Products::limit(8)->get();
        $blogs = Blogs::inRandomOrder()->limit(3)->get();
        $allproducts = Products::orderBy('id', 'desc')->limit(6)->get();
        $featureproducts = Products::inRandomOrder()->limit(4)->get();
        return view('website.index', compact('categories', 'products', 'blogs', 'allproducts', 'featureproducts'));
    }

    public function aboutus()
    {
        return view('website.aboutus');
    }

    public function thankyou($orderid)
    {
        return view('website.thankyou', compact('orderid'));
    }

    public function contactus()
    {
        $system = Setting::first();
        return view('website.contactus', compact('system'));
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['subject'] = $request->subject;
        $data['message'] = $request->message;
        ContactMessage::create($data);
        return redirect()->back()->with('success', 'Message Sent Successfully.');
    }

    public function cart()
    {
        $setting = Setting::first();
        if (Auth::guard('websiteuser')->check()) {
            $carts = Cart::where('userid', Auth::guard('websiteuser')->user()->id)->get();
        } else {
            $carts = array();
        }
        return view("website.cart", compact('carts','setting'));
    }

    public function delete_cart_product($id)
    {
        $carts = Cart::findOrFail($id)->delete();
        return redirect()->back()->with('success', 'Successfully Deleted.');
    }

    public function checkout()
    {
        $setting = Setting::first();
        if (Auth::guard('websiteuser')->check()) {
            $carts = Cart::where('userid', Auth::guard('websiteuser')->user()->id)->get();
        } else {
            $carts = array();
        }
        return view("website.checkout", compact('carts','setting'));
    }

    public function login()
    {
        if (Auth::guard('websiteuser')->check()) {
            return redirect()->route('/');

        } else {
            return view('website.login');
        }
    }

    public function customerlogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required',
            'password' => 'required|min:8'
        ]);
        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator);
        }
        if (Auth::guard('websiteuser')->attempt(['email' => $request->email, 'password' => $request->password, 'type' => 'user'])) {
            if (Auth::guard('websiteuser')->user()->status == "inactive") {
                Auth::guard('websiteuser')->logout();
                return redirect()->back()->with('error', 'Account Inactive / Blocked ! Please Contact with Customer support.')->withErrors("Account Inactive / Blocked ! Please Contact with Customer support.");
            } else {

                if (Auth::guard('websiteuser')->user()->email_verification == "unverified") {
                    Auth::guard('websiteuser')->logout();
                    return redirect()->back()->with('error', 'Email Not Verified.Please verify your email.')->withErrors("Email Not Verified.Please verify your email.");
                } else {
                    if (Auth::guard('websiteuser')->check()) {
                        return redirect()->route('user.dashboard');
                    }
                }
            }
        } else {
            return redirect()->back()->with('error', 'Invalid Email or Password !')->withInput()->withErrors("Invalid Email or Password !");
        }

    }

    public function signup()
    {
        if (Auth::guard('websiteuser')->check()) {
            return redirect()->route('/');

        } else {
            return view('website.signup');
        }
    }

    public function save_register_user(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|unique:users,email',
            'password' => 'min:8|required_with:password_confirmation|same:password_confirmation',
            'password_confirmation' => 'min:8'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator);
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['password'] = Hash::make($request->password);
        $userdata = User::create($data);
        $maildata = $userdata;
        Mail::to($request->email)->send(new AccountConfirmation($maildata));
        return redirect()->route('login')->with('success', 'Successfully Registered.Check your email.');
    }

    public function verifyaccount($id)
    {
        $id = decrypt($id);
        $user = User::findOrFail($id);
        if ($user->email_verification == "unverified") {
            $user->email_verified_at = Carbon::now();
            $user->email_verification = "verified";
            $user->status = "active";
            $user->save();
            return redirect()->route('login')->with('success', 'Email Verified Successfully');
        } else {
            return redirect()->route('login')->with('error', 'Already Verified.');
        }

    }

    public function forgot()
    {
        return view('website.forgot');
    }

    public function resetpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator)->with('error', 'Email Required.')->with('error', 'Email required.');
        }

        $check = User::where('email', $request->email)->where('type', 'user')->first();
        $setting = Setting::first();
        if ($check) {
            if ($check->status == "active") {

                $check->remember_token = Str::random(30);
                $check->save();
                $maildata = $check;
                Mail::to($request->email)->send(new PasswordResetMail($maildata));
                return redirect()->route('login')->with('success', 'Password Sent ! Please Check your email.')->with('success', 'Password Sent ! Please Check your email.');
            } else {
                return back()
                    ->withInput()
                    ->withErrors('Your account is not active please contact with customer support.')->with('error', 'Your account is not active please contact with customer support.');
            }
        } else {
            return back()
                ->withInput()
                ->withErrors('Invalid email !Please enter valid email ')->with('error', 'Invalid Email.');
        }

    }

    public function resetnewpassword($email)
    {
        $decemail = decrypt($email);
        $check = User::where('email', $decemail)->whereNotNull('remember_token')->count();
        if ($check > 0) {
            return view('website.resetnewpassword', compact('email'));
        } else {
            return redirect()->route('login')->with('error', 'Link Expired Please Reset Your Password Again !');
        }
    }

    public function saveresetnewpassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password' => 'min:8|required_with:password_confirmation|same:password_confirmation',
            'password_confirmation' => 'min:8'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator)->with('error', 'Password Not Match / Required.')->with('error', 'Password Not Match / Required.');
        }

        $email = decrypt($request->id);
        $user = User::where('email', $email)->first();
        $user->password = Hash::make($request->password);;
        $user->remember_token = NULL;
        $user->save();
        return redirect()->route('login')->with('success', 'Password Successfully Updated !');
    }

    public function privacypolicy()
    {
        return view('website.privacypolicy');
    }

    public function deliveryreturn()
    {
        return view('website.deliveryreturn');
    }

    public function save_order(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'fname' => 'required',
            'lname' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'address' => 'required',
            'city' => 'required',
            'total_price_of_cart' => 'required',
            'zipcode' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $order_idd = rand(1000, 1000000);
        $data['orderid'] = $order_idd;
        $data['fname'] = $request->fname;
        $data['lname'] = $request->lname;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['address'] = $request->address;
        $data['city'] = $request->city;
        $data['zipcode'] = $request->zipcode;
        $data['price'] = $request->total_price_of_cart;
        $orderData = Orders::create($data);

        $carts = Cart::where('sessionid', Session::getId())->get();
        foreach ($carts as $cart) {
            $data_Detail['orderid'] = $orderData->id;
            $data_Detail['productid'] = $cart->product->id;
            $data_Detail['product_name'] = $cart->product->name;
            $data_Detail['product_price'] = $cart->product->price;
            $data_Detail['quantity'] = $cart->quantity;
            OrderDetails::create($data_Detail);
        }
        Cart::where('sessionid', Session::getId())->delete();
        $maildata = $orderData;
        $check = Mail::to($request->email)->send(new OrderConfirmation($maildata));
        return redirect()->route('thankyou', [$order_idd])->with('success', 'Order Placed.');
    }

    public function shop(Request $request)
    {
        $categories = Categories::all();
        $query = Products::query();
        if (isset($request->name) && !empty($request->name)) {
            $query->where('name', 'like', '%' . $request->name . '%');
        }
        if (isset($request->categories) && !empty($request->categories)) {
            $query->whereIn('categoryid', $request->categories);
        }
//        if (isset($request->minimum) && !empty($request->minimum)) {
//            $query->where('price', '>=', $request->minimum);
//        }
//        if (isset($request->maximum) && !empty($request->maximum)) {
//            $query->where('price', '<=', $request->maximum);
//        }
        if (isset($request->amount) && !empty($request->amount)) {

            if (preg_match('/\$(\d+)\s*-\s*\$(\d+)/', $request->amount, $matches)) {
                $firstPrice = $matches[1];  // The first price
                $secondPrice = $matches[2]; // The second price

                // Convert to integers if needed
                $firstPrice = (int)$firstPrice;
                $secondPrice = (int)$secondPrice;
                $query->where('price', '>=', $firstPrice);
                $query->where('price', '<=', $secondPrice);

            } else {
                return redirect()->back()->with('error', 'Invalid Price.');
            }

        }
        $allproducts = $query->paginate('12');
        return view('website.shop', compact('allproducts', 'categories', 'request'));
    }

    public function product_detail($slug)
    {
        $product = Products::where('slug', $slug)->first();
        $relatedproducts = Products::where('categoryid', $product->categoryid)->inRandomOrder()->limit(4)->get();
        return view('website.product_detail', compact('product', 'relatedproducts'));
    }

    public function blogs(Request $request)
    {
        $query = Blogs::query();
        if (isset($request->category) && !empty($request->category)) {
            $query->where('category', $request->category);
        }
        $blogs = $query->inRandomOrder()->paginate(9);
        return view('website.blogs', compact('blogs'));
    }

    public function blog_detail($slug)
    {
        $blog = Blogs::where('slug', $slug)->first();
        $relatedBlogs = Blogs::limit(6)->get();
        $categories = Blogscategories::all();
        return view('website.blog_detail', compact('blog', 'relatedBlogs', 'categories'));
    }

    public function add_to_cart_single($productid)
    {
        if (Auth::guard('websiteuser')->check()) {

            $check = Cart::where('userid', Auth::guard('websiteuser')->user()->id)->where('productid', $productid)->count();
            if ($check > 0) {
                $checkProduct = Cart::where('userid', Auth::guard('websiteuser')->user()->id)->where('productid', $productid)->first();
                $checkProduct->quantity = ($checkProduct->quantity + 1);
                $checkProduct->update();
                return redirect()->back()->with('success', 'Successfully Updated.');
            } else {
                $data['userid'] = Auth::guard('websiteuser')->user()->id;
                $data['productid'] = $productid;
                $data['quantity'] = 1;
                Cart::create($data);
                return redirect()->back()->with('success', 'Successfully Added.');
            }
        } else {
            return redirect()->route('login')->with('error', 'Please login first to use add to cart.');
        }
    }

    public function add_to_cart_from_detail(Request $request)
    {
        if (Auth::guard('websiteuser')->check()) {

            $check = Cart::where('userid', Auth::guard('websiteuser')->user()->id)->where('productid', $request->productid)->count();
            if ($check > 0) {
                $checkProduct = Cart::where('userid', Auth::guard('websiteuser')->user()->id)->where('productid', $request->productid)->first();
                $checkProduct->quantity = $request->quantity;
                if (isset($request->color) && !empty($request->color)) {
                    $checkProduct->color = $request->color;
                }
                $checkProduct->update();
                return redirect()->back()->with('success', 'Successfully Updated.');
            } else {
                $data['userid'] = Auth::guard('websiteuser')->user()->id;
                $data['productid'] = $request->productid;
                $data['quantity'] = $request->quantity;
                if (isset($request->color) && !empty($request->color)) {
                    $data['color'] = $request->color;
                }
                Cart::create($data);
                return redirect()->back()->with('success', 'Successfully Added.');
            }
        } else {
            return redirect()->route('login')->with('error', 'Please login first to use add to cart.');
        }
    }

    public function update_cart($id, $val)
    {
        $checkProduct = Cart::findOrFail($id);
        $checkProduct->quantity = $val;
        $checkProduct->update();
//        foreach ($request->quantity as $productid => $quan) {
//            $checkProduct = Cart::where('sessionid', Session::getId())->where('productid', $productid)->first();
//            $checkProduct->quantity = $quan;
//            $checkProduct->update();
//        }
        return redirect()->back()->with('success', 'Successfully Updated.');
    }

    public function mail($orderid)
    {
        $maildata = Orders::findOrFail($orderid);
        return view('website.mail', compact('maildata'));
    }
}
