<?php

namespace App\Http\Controllers;

use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\Orders;
use App\Models\Products;
use App\Models\Setting;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class WebsiteUserController extends Controller
{
    public function Dashboard()
    {
        $website = Setting::first();
        return view('user.index', compact('website'));
    }

    public function logout(Request $request)
    {
        Auth::guard('websiteuser')->logout();
        return redirect()->route("/");
    }

    public function userprofile(Request $request)
    {
        $user = Auth::guard('websiteuser')->user();
        return view('user.profile', compact('user'));
    }

    public function updateuserprofile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'address' => 'required',
            'phone' => 'required'
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }

//        update user
        $getData = user::findOrFail(Auth::guard('websiteuser')->user()->id);
        $getData->name = $request->name;
        $getData->phone = $request->phone;
        $getData->address = $request->address;
        if (isset($request->password)) {
            $validator = Validator::make($request->all(), [
                'password' => 'required|min:8'
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('error', 'Minimum 8 Characters Required for password.');
            }
            $getData->password = Hash::make($request->password);
        }
        if ($request->hasFile('profile')) {
            $validator = Validator::make($request->all(), [
                'profile' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Profile Picture');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('profile');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return redirect()->back()->with('success', 'Data Successfully Updated !');
    }

}
